Task: MWSC pronoun resolution
==============================
Description: Resolving possible ambiguous pronouns. Implemented as part of the DecaNLPtask, and can be found on the decaNLP github

Tags: #mwsc, #All, #decanlp

